==> centreon-web-24.04.19.tar.gz: centreon-web-24.04.19/www/include/reporting/dashboard/xmlInformations/initXmlFeed.php <==
<?php
/*
 * Copyright 2005-2016 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License as published by the Free Software 
 * Foundation ; either version 2 of the License.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with 
 * this program; if not, see <http://www.gnu.org/licenses>.
 * 
 * Linking this program statically or dynamically with other modules is making a 
 * combined work based on this program. Thus, the terms and conditions of the GNU 
 * General Public License cover the whole combination.
 * 
 * As a special exception, the copyright holders of this program give Centreon 
 * permission to link this program with independent modules to produce an executable, 
 * regardless of the license terms of these independent modules, and to copy and 
 * distribute the resulting executable under terms of Centreon choice, provided that 
 * Centreon also meet, for each linked independent module, the terms  and conditions 
 * of the license of that module. An independent module is a module which is not 
 * derived from this program. If you modify this program, you may extend this 
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 * 
 * For more information : contact@centreon.com
 * 
 */

require_once realpath(dirname(__FILE__) . "/../../../../../config/centreon.config.php");

require_once _CENTREON_PATH_."www/class/centreon.class.php";
require_once _CENTREON_PATH_."www/class/centreonUser.class.php";
require_once _CENTREON_PATH_."www/class/centreonXML.class.php";
require_once _CENTREON_PATH_."www/class/centreonDB.class.php";
require_once _CENTREON_PATH_."www/class/centreonDuration.class.php";
require_once _CENTREON_PATH_."www/class/centreonACL.class.php";
require_once _CENTREON_PATH_."www/include/reporting/dashboard/DB-Func.php";
require_once _CENTREON_PATH_."www/include/reporting/dashboard/common-Func.php";
require_once _CENTREON_PATH_."www/include/reporting/dashboard/xmlInformations/common-Func.php";

session_start();

if (isset($_SESSION['centreon'])) {
    $centreon = $_SESSION['centreon'];
} else {
    exit();
}

$buffer = new CentreonXML();
$buffer->startElement("data");

$pearDB = new CentreonDB();
$pearDBO = new CentreonDB("centstorage");

$sid = session_id();

$DBRESULT = $pearDB->query("SELECT * FROM session WHERE session_id = '" . $pearDB->escape($sid) . "'");
if (!$DBRESULT->rowCount()) {
    exit();
}

/*
 * Definition of status
 */
$state = array();
$statesTab = array();
if ($stateType == 'host') {
    $state["UP"] = _("UP");
    $state["DOWN"] = _("DOWN");
    $state["UNREACHABLE"] = _("UNREACHABLE");
    $state["UNDETERMINED"] = _("UNDETERMINED");
    $statesTab[] = "UP";
    $statesTab[] = "DOWN";
    $statesTab[] = "UNREACHABLE";
} elseif ($stateType == 'service') {
    $state["OK"] = _("OK");
    $state["WARNING"] = _("WARNING");
    $state["CRITICAL"] = _("CRITICAL");
    $state["UNKNOWN"] = _("UNKNOWN");
    $state["UNDETERMINED"] = _("UNDETERMINED");
    $statesTab[] = "OK";
    $statesTab[] = "WARNING";
    $statesTab[] = "CRITICAL";
    $statesTab[] = "UNKNOWN";
}

==> centreon-web-24.11.0.tar.gz: centreon-web-24.11.0/www/include/reporting/dashboard/xmlInformations/initXmlFeed.php <==
<?php
/*
 * Copyright 2005-2016 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License as published by the Free Software 
 * Foundation ; either version 2 of the License.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with 
 * this program; if not, see <http://www.gnu.org/licenses>.
 * 
 * Linking this program statically or dynamically with other modules is making a 
 * combined work based on this program. Thus, the terms and conditions of the GNU 
 * General Public License cover the whole combination.
 * 
 * As a special exception, the copyright holders of this program give Centreon 
 * permission to link this program with independent modules to produce an executable, 
 * regardless of the license terms of these independent modules, and to copy and 
 * distribute the resulting executable under terms of Centreon choice, provided that 
 * Centreon also meet, for each linked independent module, the terms  and conditions 
 * of the license of that module. An independent module is a module which is not 
 * derived from this program. If you modify this program, you may extend this 
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 * 
 * For more information : contact@centreon.com
 * 
 */

require_once realpath(__DIR__ . "/../../../../../config/centreon.config.php");

require_once _CENTREON_PATH_."www/class/centreon.class.php";
require_once _CENTREON_PATH_."www/class/centreonUser.class.php";
require_once _CENTREON_PATH_."www/class/centreonXML.class.php";
require_once _CENTREON_PATH_."www/class/centreonDB.class.php";
require_once _CENTREON_PATH_."www/class/centreonDuration.class.php";
require_once _CENTREON_PATH_."www/class/centreonACL.class.php";
require_once _CENTREON_PATH_."www/include/reporting/dashboard/DB-Func.php";
require_once _CENTREON_PATH_."www/include/reporting/dashboard/common-Func.php";
require_once _CENTREON_PATH_."www/include/reporting/dashboard/xmlInformations/common-Func.php";

session_start();

if (isset($_SESSION['centreon'])) {
    $centreon = $_SESSION['centreon'];
} else {
    exit();
}

$buffer = new CentreonXML();
$buffer->startElement("data");

$pearDB = new CentreonDB();
$pearDBO = new CentreonDB("centstorage");

$sid = session_id();

$DBRESULT = $pearDB->query("SELECT * FROM session WHERE session_id = '" . $pearDB->escape($sid) . "'");
if (!$DBRESULT->rowCount()) {
    exit();
}

/*
 * Definition of status
 */
$state = [];
$statesTab = [];
if ($stateType == 'host') {
    $state["UP"] = _("UP");
    $state["DOWN"] = _("DOWN");
    $state["UNREACHABLE"] = _("UNREACHABLE");
    $state["UNDETERMINED"] = _("UNDETERMINED");
    $statesTab[] = "UP";
    $statesTab[] = "DOWN";
    $statesTab[] = "UNREACHABLE";
} elseif ($stateType == 'service') {
    $state["OK"] = _("OK");
    $state["WARNING"] = _("WARNING");
    $state["CRITICAL"] = _("CRITICAL");
    $state["UNKNOWN"] = _("UNKNOWN");
    $state["UNDETERMINED"] = _("UNDETERMINED");
    $statesTab[] = "OK";
    $statesTab[] = "WARNING";
    $statesTab[] = "CRITICAL";
    $statesTab[] = "UNKNOWN";
}
